# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GrantDatabaseDefaultPrivilegeArgs', 'GrantDatabaseDefaultPrivilege']

@pulumi.input_type
class GrantDatabaseDefaultPrivilegeArgs:
    def __init__(__self__, *,
                 grantee_name: pulumi.Input[_builtins.str],
                 privilege: pulumi.Input[_builtins.str],
                 target_role_name: pulumi.Input[_builtins.str],
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GrantDatabaseDefaultPrivilege resource.
        :param pulumi.Input[_builtins.str] grantee_name: The role name that will gain the default privilege. Use the `PUBLIC` pseudo-role to grant privileges to all roles.
        :param pulumi.Input[_builtins.str] privilege: The privilege to grant to the object.
        :param pulumi.Input[_builtins.str] target_role_name: The default privilege will apply to objects created by this role. If this is left blank, then the current role is assumed. Use the `PUBLIC` pseudo-role to target objects created by all roles.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        """
        pulumi.set(__self__, "grantee_name", grantee_name)
        pulumi.set(__self__, "privilege", privilege)
        pulumi.set(__self__, "target_role_name", target_role_name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="granteeName")
    def grantee_name(self) -> pulumi.Input[_builtins.str]:
        """
        The role name that will gain the default privilege. Use the `PUBLIC` pseudo-role to grant privileges to all roles.
        """
        return pulumi.get(self, "grantee_name")

    @grantee_name.setter
    def grantee_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "grantee_name", value)

    @_builtins.property
    @pulumi.getter
    def privilege(self) -> pulumi.Input[_builtins.str]:
        """
        The privilege to grant to the object.
        """
        return pulumi.get(self, "privilege")

    @privilege.setter
    def privilege(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "privilege", value)

    @_builtins.property
    @pulumi.getter(name="targetRoleName")
    def target_role_name(self) -> pulumi.Input[_builtins.str]:
        """
        The default privilege will apply to objects created by this role. If this is left blank, then the current role is assumed. Use the `PUBLIC` pseudo-role to target objects created by all roles.
        """
        return pulumi.get(self, "target_role_name")

    @target_role_name.setter
    def target_role_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "target_role_name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _GrantDatabaseDefaultPrivilegeState:
    def __init__(__self__, *,
                 grantee_name: Optional[pulumi.Input[_builtins.str]] = None,
                 privilege: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 target_role_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GrantDatabaseDefaultPrivilege resources.
        :param pulumi.Input[_builtins.str] grantee_name: The role name that will gain the default privilege. Use the `PUBLIC` pseudo-role to grant privileges to all roles.
        :param pulumi.Input[_builtins.str] privilege: The privilege to grant to the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] target_role_name: The default privilege will apply to objects created by this role. If this is left blank, then the current role is assumed. Use the `PUBLIC` pseudo-role to target objects created by all roles.
        """
        if grantee_name is not None:
            pulumi.set(__self__, "grantee_name", grantee_name)
        if privilege is not None:
            pulumi.set(__self__, "privilege", privilege)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if target_role_name is not None:
            pulumi.set(__self__, "target_role_name", target_role_name)

    @_builtins.property
    @pulumi.getter(name="granteeName")
    def grantee_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The role name that will gain the default privilege. Use the `PUBLIC` pseudo-role to grant privileges to all roles.
        """
        return pulumi.get(self, "grantee_name")

    @grantee_name.setter
    def grantee_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "grantee_name", value)

    @_builtins.property
    @pulumi.getter
    def privilege(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The privilege to grant to the object.
        """
        return pulumi.get(self, "privilege")

    @privilege.setter
    def privilege(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privilege", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="targetRoleName")
    def target_role_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default privilege will apply to objects created by this role. If this is left blank, then the current role is assumed. Use the `PUBLIC` pseudo-role to target objects created by all roles.
        """
        return pulumi.get(self, "target_role_name")

    @target_role_name.setter
    def target_role_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_role_name", value)


@pulumi.type_token("materialize:index/grantDatabaseDefaultPrivilege:GrantDatabaseDefaultPrivilege")
class GrantDatabaseDefaultPrivilege(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 grantee_name: Optional[pulumi.Input[_builtins.str]] = None,
                 privilege: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 target_role_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Defines default privileges that will be applied to objects created in the future. It does not affect any existing objects.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Grant role the privilege USAGE for objects in the database database
        example = materialize.GrantDatabaseDefaultPrivilege("example",
            grantee_name="grantee",
            privilege="USAGE",
            target_role_name="target_role")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Grants can be imported using the concatenation of GRANT DEFAULT and the grantee id of the role.

        Optionally, you can include the target id and database id. The privilege is required.

        ```sh
        $ pulumi import materialize:index/grantDatabaseDefaultPrivilege:GrantDatabaseDefaultPrivilege example <region>:GRANT DEFAULT|CONNECTION|<grantee_id>|<target_role_id>|<database_id>||<privilege>
        ```

        The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] grantee_name: The role name that will gain the default privilege. Use the `PUBLIC` pseudo-role to grant privileges to all roles.
        :param pulumi.Input[_builtins.str] privilege: The privilege to grant to the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] target_role_name: The default privilege will apply to objects created by this role. If this is left blank, then the current role is assumed. Use the `PUBLIC` pseudo-role to target objects created by all roles.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GrantDatabaseDefaultPrivilegeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Defines default privileges that will be applied to objects created in the future. It does not affect any existing objects.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        # Grant role the privilege USAGE for objects in the database database
        example = materialize.GrantDatabaseDefaultPrivilege("example",
            grantee_name="grantee",
            privilege="USAGE",
            target_role_name="target_role")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Grants can be imported using the concatenation of GRANT DEFAULT and the grantee id of the role.

        Optionally, you can include the target id and database id. The privilege is required.

        ```sh
        $ pulumi import materialize:index/grantDatabaseDefaultPrivilege:GrantDatabaseDefaultPrivilege example <region>:GRANT DEFAULT|CONNECTION|<grantee_id>|<target_role_id>|<database_id>||<privilege>
        ```

        The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param GrantDatabaseDefaultPrivilegeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GrantDatabaseDefaultPrivilegeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 grantee_name: Optional[pulumi.Input[_builtins.str]] = None,
                 privilege: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 target_role_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GrantDatabaseDefaultPrivilegeArgs.__new__(GrantDatabaseDefaultPrivilegeArgs)

            if grantee_name is None and not opts.urn:
                raise TypeError("Missing required property 'grantee_name'")
            __props__.__dict__["grantee_name"] = grantee_name
            if privilege is None and not opts.urn:
                raise TypeError("Missing required property 'privilege'")
            __props__.__dict__["privilege"] = privilege
            __props__.__dict__["region"] = region
            if target_role_name is None and not opts.urn:
                raise TypeError("Missing required property 'target_role_name'")
            __props__.__dict__["target_role_name"] = target_role_name
        super(GrantDatabaseDefaultPrivilege, __self__).__init__(
            'materialize:index/grantDatabaseDefaultPrivilege:GrantDatabaseDefaultPrivilege',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            grantee_name: Optional[pulumi.Input[_builtins.str]] = None,
            privilege: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            target_role_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'GrantDatabaseDefaultPrivilege':
        """
        Get an existing GrantDatabaseDefaultPrivilege resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] grantee_name: The role name that will gain the default privilege. Use the `PUBLIC` pseudo-role to grant privileges to all roles.
        :param pulumi.Input[_builtins.str] privilege: The privilege to grant to the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.str] target_role_name: The default privilege will apply to objects created by this role. If this is left blank, then the current role is assumed. Use the `PUBLIC` pseudo-role to target objects created by all roles.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GrantDatabaseDefaultPrivilegeState.__new__(_GrantDatabaseDefaultPrivilegeState)

        __props__.__dict__["grantee_name"] = grantee_name
        __props__.__dict__["privilege"] = privilege
        __props__.__dict__["region"] = region
        __props__.__dict__["target_role_name"] = target_role_name
        return GrantDatabaseDefaultPrivilege(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="granteeName")
    def grantee_name(self) -> pulumi.Output[_builtins.str]:
        """
        The role name that will gain the default privilege. Use the `PUBLIC` pseudo-role to grant privileges to all roles.
        """
        return pulumi.get(self, "grantee_name")

    @_builtins.property
    @pulumi.getter
    def privilege(self) -> pulumi.Output[_builtins.str]:
        """
        The privilege to grant to the object.
        """
        return pulumi.get(self, "privilege")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="targetRoleName")
    def target_role_name(self) -> pulumi.Output[_builtins.str]:
        """
        The default privilege will apply to objects created by this role. If this is left blank, then the current role is assumed. Use the `PUBLIC` pseudo-role to target objects created by all roles.
        """
        return pulumi.get(self, "target_role_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SSODomainArgs', 'SSODomain']

@pulumi.input_type
class SSODomainArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[_builtins.str],
                 sso_config_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a SSODomain resource.
        :param pulumi.Input[_builtins.str] domain: The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        :param pulumi.Input[_builtins.str] sso_config_id: The ID of the associated SSO configuration.
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "sso_config_id", sso_config_id)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Input[_builtins.str]:
        """
        The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")

    @sso_config_id.setter
    def sso_config_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "sso_config_id", value)


@pulumi.input_type
class _SSODomainState:
    def __init__(__self__, *,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_config_id: Optional[pulumi.Input[_builtins.str]] = None,
                 validated: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering SSODomain resources.
        :param pulumi.Input[_builtins.str] domain: The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        :param pulumi.Input[_builtins.str] sso_config_id: The ID of the associated SSO configuration.
        :param pulumi.Input[_builtins.bool] validated: Indicates whether the domain has been validated.
        """
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if sso_config_id is not None:
            pulumi.set(__self__, "sso_config_id", sso_config_id)
        if validated is not None:
            pulumi.set(__self__, "validated", validated)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")

    @sso_config_id.setter
    def sso_config_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sso_config_id", value)

    @_builtins.property
    @pulumi.getter
    def validated(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the domain has been validated.
        """
        return pulumi.get(self, "validated")

    @validated.setter
    def validated(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "validated", value)


@pulumi.type_token("materialize:index/sSODomain:SSODomain")
class SSODomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_config_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The SSO domain resource allows you to set the domain for an SSO configuration. This domain will be used to validate the SSO configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sso_domain = materialize.SSODomain("exampleSsoDomain",
            domain="example.com",
            sso_config_id=materialize_sso_config["example_sso_config"]["id"])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Retrieve the SSO Configuration ID using the materialize_sso_config data source

        Example of using the data source in your configuration:

        data "materialize_sso_config" "all" {}

        output "sso_config_output" {

            value = data.materialize_sso_config.all

        }

        The SSO Configuration ID can be retrieved using the following command:

        terraform output sso_config_output

        Import command:

        ```sh
        $ pulumi import materialize:index/sSODomain:SSODomain example <sso_config_id>:<domain.com>
        ```

        Note: Replace <sso_config_id> with the actual ID of the SSO configuration

        and <domain.com> with the actual domain you want to import

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain: The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        :param pulumi.Input[_builtins.str] sso_config_id: The ID of the associated SSO configuration.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SSODomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The SSO domain resource allows you to set the domain for an SSO configuration. This domain will be used to validate the SSO configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_sso_domain = materialize.SSODomain("exampleSsoDomain",
            domain="example.com",
            sso_config_id=materialize_sso_config["example_sso_config"]["id"])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Retrieve the SSO Configuration ID using the materialize_sso_config data source

        Example of using the data source in your configuration:

        data "materialize_sso_config" "all" {}

        output "sso_config_output" {

            value = data.materialize_sso_config.all

        }

        The SSO Configuration ID can be retrieved using the following command:

        terraform output sso_config_output

        Import command:

        ```sh
        $ pulumi import materialize:index/sSODomain:SSODomain example <sso_config_id>:<domain.com>
        ```

        Note: Replace <sso_config_id> with the actual ID of the SSO configuration

        and <domain.com> with the actual domain you want to import

        :param str resource_name: The name of the resource.
        :param SSODomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SSODomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 sso_config_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SSODomainArgs.__new__(SSODomainArgs)

            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            if sso_config_id is None and not opts.urn:
                raise TypeError("Missing required property 'sso_config_id'")
            __props__.__dict__["sso_config_id"] = sso_config_id
            __props__.__dict__["validated"] = None
        super(SSODomain, __self__).__init__(
            'materialize:index/sSODomain:SSODomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain: Optional[pulumi.Input[_builtins.str]] = None,
            sso_config_id: Optional[pulumi.Input[_builtins.str]] = None,
            validated: Optional[pulumi.Input[_builtins.bool]] = None) -> 'SSODomain':
        """
        Get an existing SSODomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain: The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        :param pulumi.Input[_builtins.str] sso_config_id: The ID of the associated SSO configuration.
        :param pulumi.Input[_builtins.bool] validated: Indicates whether the domain has been validated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SSODomainState.__new__(_SSODomainState)

        __props__.__dict__["domain"] = domain
        __props__.__dict__["sso_config_id"] = sso_config_id
        __props__.__dict__["validated"] = validated
        return SSODomain(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Output[_builtins.str]:
        """
        The domain name for the SSO domain configuration. This domain will be used to validate the SSO configuration and needs to be unique across all SSO configurations.
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter(name="ssoConfigId")
    def sso_config_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the associated SSO configuration.
        """
        return pulumi.get(self, "sso_config_id")

    @_builtins.property
    @pulumi.getter
    def validated(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether the domain has been validated.
        """
        return pulumi.get(self, "validated")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetSecretsResult',
    'AwaitableGetSecretsResult',
    'get_secrets',
    'get_secrets_output',
]

@pulumi.output_type
class GetSecretsResult:
    """
    A collection of values returned by GetSecrets.
    """
    def __init__(__self__, database_name=None, id=None, region=None, schema_name=None, secrets=None):
        if database_name and not isinstance(database_name, str):
            raise TypeError("Expected argument 'database_name' to be a str")
        pulumi.set(__self__, "database_name", database_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if schema_name and not isinstance(schema_name, str):
            raise TypeError("Expected argument 'schema_name' to be a str")
        pulumi.set(__self__, "schema_name", schema_name)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[_builtins.str]:
        """
        Limit secrets to a specific database
        """
        return pulumi.get(self, "database_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[_builtins.str]:
        """
        Limit secrets to a specific schema within a specific database
        """
        return pulumi.get(self, "schema_name")

    @_builtins.property
    @pulumi.getter
    def secrets(self) -> Sequence['outputs.GetSecretsSecretResult']:
        """
        The secrets in the account
        """
        return pulumi.get(self, "secrets")


class AwaitableGetSecretsResult(GetSecretsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecretsResult(
            database_name=self.database_name,
            id=self.id,
            region=self.region,
            schema_name=self.schema_name,
            secrets=self.secrets)


def get_secrets(database_name: Optional[_builtins.str] = None,
                region: Optional[_builtins.str] = None,
                schema_name: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecretsResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_secrets()
    materialize = materialize.get_secrets(database_name="materialize")
    materialize_schema = materialize.get_secrets(database_name="materialize",
        schema_name="schema")
    ```


    :param _builtins.str database_name: Limit secrets to a specific database
    :param _builtins.str region: The region in which the resource is located.
    :param _builtins.str schema_name: Limit secrets to a specific schema within a specific database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['region'] = region
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getSecrets:GetSecrets', __args__, opts=opts, typ=GetSecretsResult).value

    return AwaitableGetSecretsResult(
        database_name=pulumi.get(__ret__, 'database_name'),
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'),
        schema_name=pulumi.get(__ret__, 'schema_name'),
        secrets=pulumi.get(__ret__, 'secrets'))
def get_secrets_output(database_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       schema_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecretsResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_secrets()
    materialize = materialize.get_secrets(database_name="materialize")
    materialize_schema = materialize.get_secrets(database_name="materialize",
        schema_name="schema")
    ```


    :param _builtins.str database_name: Limit secrets to a specific database
    :param _builtins.str region: The region in which the resource is located.
    :param _builtins.str schema_name: Limit secrets to a specific schema within a specific database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['region'] = region
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('materialize:index/getSecrets:GetSecrets', __args__, opts=opts, typ=GetSecretsResult)
    return __ret__.apply(lambda __response__: GetSecretsResult(
        database_name=pulumi.get(__response__, 'database_name'),
        id=pulumi.get(__response__, 'id'),
        region=pulumi.get(__response__, 'region'),
        schema_name=pulumi.get(__response__, 'schema_name'),
        secrets=pulumi.get(__response__, 'secrets')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetSinksResult',
    'AwaitableGetSinksResult',
    'get_sinks',
    'get_sinks_output',
]

@pulumi.output_type
class GetSinksResult:
    """
    A collection of values returned by GetSinks.
    """
    def __init__(__self__, database_name=None, id=None, region=None, schema_name=None, sinks=None):
        if database_name and not isinstance(database_name, str):
            raise TypeError("Expected argument 'database_name' to be a str")
        pulumi.set(__self__, "database_name", database_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if schema_name and not isinstance(schema_name, str):
            raise TypeError("Expected argument 'schema_name' to be a str")
        pulumi.set(__self__, "schema_name", schema_name)
        if sinks and not isinstance(sinks, list):
            raise TypeError("Expected argument 'sinks' to be a list")
        pulumi.set(__self__, "sinks", sinks)

    @_builtins.property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[_builtins.str]:
        """
        Limit sinks to a specific database
        """
        return pulumi.get(self, "database_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region in which the resource is located.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[_builtins.str]:
        """
        Limit sinks to a specific schema within a specific database
        """
        return pulumi.get(self, "schema_name")

    @_builtins.property
    @pulumi.getter
    def sinks(self) -> Sequence['outputs.GetSinksSinkResult']:
        """
        The sinks in the account
        """
        return pulumi.get(self, "sinks")


class AwaitableGetSinksResult(GetSinksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSinksResult(
            database_name=self.database_name,
            id=self.id,
            region=self.region,
            schema_name=self.schema_name,
            sinks=self.sinks)


def get_sinks(database_name: Optional[_builtins.str] = None,
              region: Optional[_builtins.str] = None,
              schema_name: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSinksResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_sinks()
    materialize = materialize.get_sinks(database_name="materialize")
    materialize_schema = materialize.get_sinks(database_name="materialize",
        schema_name="schema")
    ```


    :param _builtins.str database_name: Limit sinks to a specific database
    :param _builtins.str region: The region in which the resource is located.
    :param _builtins.str schema_name: Limit sinks to a specific schema within a specific database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['region'] = region
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/getSinks:GetSinks', __args__, opts=opts, typ=GetSinksResult).value

    return AwaitableGetSinksResult(
        database_name=pulumi.get(__ret__, 'database_name'),
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'),
        schema_name=pulumi.get(__ret__, 'schema_name'),
        sinks=pulumi.get(__ret__, 'sinks'))
def get_sinks_output(database_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     schema_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSinksResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.get_sinks()
    materialize = materialize.get_sinks(database_name="materialize")
    materialize_schema = materialize.get_sinks(database_name="materialize",
        schema_name="schema")
    ```


    :param _builtins.str database_name: Limit sinks to a specific database
    :param _builtins.str region: The region in which the resource is located.
    :param _builtins.str schema_name: Limit sinks to a specific schema within a specific database
    """
    __args__ = dict()
    __args__['databaseName'] = database_name
    __args__['region'] = region
    __args__['schemaName'] = schema_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('materialize:index/getSinks:GetSinks', __args__, opts=opts, typ=GetSinksResult)
    return __ret__.apply(lambda __response__: GetSinksResult(
        database_name=pulumi.get(__response__, 'database_name'),
        id=pulumi.get(__response__, 'id'),
        region=pulumi.get(__response__, 'region'),
        schema_name=pulumi.get(__response__, 'schema_name'),
        sinks=pulumi.get(__response__, 'sinks')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 availability_zones: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 disk: Optional[pulumi.Input[_builtins.bool]] = None,
                 identify_by_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 scheduling: Optional[pulumi.Input['ClusterSchedulingArgs']] = None,
                 size: Optional[pulumi.Input[_builtins.str]] = None,
                 wait_until_ready: Optional[pulumi.Input['ClusterWaitUntilReadyArgs']] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] availability_zones: The specific availability zones of the cluster.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.bool] disk: **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        :param pulumi.Input[_builtins.bool] identify_by_name: Use the cluster name as the resource identifier in your state file, rather than the internal cluster ID. This is particularly useful in scenarios like dbt-materialize blue/green deployments, where clusters are swapped but the ID changes. By identifying by name, the resource can be managed consistently even when the underlying cluster ID is updated.
        :param pulumi.Input[_builtins.bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[_builtins.str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[_builtins.str] name: The identifier for the cluster.
        :param pulumi.Input[_builtins.str] ownership_role: The owernship role of the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.int] replication_factor: The number of replicas of each dataflow-powered object to maintain.
        :param pulumi.Input['ClusterSchedulingArgs'] scheduling: Defines the scheduling parameters for the cluster.
        :param pulumi.Input[_builtins.str] size: The size of the managed cluster.
        :param pulumi.Input['ClusterWaitUntilReadyArgs'] wait_until_ready: Defines the parameters for the WAIT UNTIL READY options
        """
        if availability_zones is not None:
            pulumi.set(__self__, "availability_zones", availability_zones)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if disk is not None:
            warnings.warn("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""", DeprecationWarning)
            pulumi.log.warn("""disk is deprecated: Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
        if disk is not None:
            pulumi.set(__self__, "disk", disk)
        if identify_by_name is not None:
            pulumi.set(__self__, "identify_by_name", identify_by_name)
        if introspection_debugging is not None:
            pulumi.set(__self__, "introspection_debugging", introspection_debugging)
        if introspection_interval is not None:
            pulumi.set(__self__, "introspection_interval", introspection_interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if replication_factor is not None:
            pulumi.set(__self__, "replication_factor", replication_factor)
        if scheduling is not None:
            pulumi.set(__self__, "scheduling", scheduling)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if wait_until_ready is not None:
            pulumi.set(__self__, "wait_until_ready", wait_until_ready)

    @_builtins.property
    @pulumi.getter(name="availabilityZones")
    def availability_zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The specific availability zones of the cluster.
        """
        return pulumi.get(self, "availability_zones")

    @availability_zones.setter
    def availability_zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "availability_zones", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
    def disk(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        """
        return pulumi.get(self, "disk")

    @disk.setter
    def disk(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disk", value)

    @_builtins.property
    @pulumi.getter(name="identifyByName")
    def identify_by_name(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the cluster name as the resource identifier in your state file, rather than the internal cluster ID. This is particularly useful in scenarios like dbt-materialize blue/green deployments, where clusters are swapped but the ID changes. By identifying by name, the resource can be managed consistently even when the underlying cluster ID is updated.
        """
        return pulumi.get(self, "identify_by_name")

    @identify_by_name.setter
    def identify_by_name(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "identify_by_name", value)

    @_builtins.property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @introspection_debugging.setter
    def introspection_debugging(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "introspection_debugging", value)

    @_builtins.property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @introspection_interval.setter
    def introspection_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "introspection_interval", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ownership_role", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of replicas of each dataflow-powered object to maintain.
        """
        return pulumi.get(self, "replication_factor")

    @replication_factor.setter
    def replication_factor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "replication_factor", value)

    @_builtins.property
    @pulumi.getter
    def scheduling(self) -> Optional[pulumi.Input['ClusterSchedulingArgs']]:
        """
        Defines the scheduling parameters for the cluster.
        """
        return pulumi.get(self, "scheduling")

    @scheduling.setter
    def scheduling(self, value: Optional[pulumi.Input['ClusterSchedulingArgs']]):
        pulumi.set(self, "scheduling", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The size of the managed cluster.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "size", value)

    @_builtins.property
    @pulumi.getter(name="waitUntilReady")
    def wait_until_ready(self) -> Optional[pulumi.Input['ClusterWaitUntilReadyArgs']]:
        """
        Defines the parameters for the WAIT UNTIL READY options
        """
        return pulumi.get(self, "wait_until_ready")

    @wait_until_ready.setter
    def wait_until_ready(self, value: Optional[pulumi.Input['ClusterWaitUntilReadyArgs']]):
        pulumi.set(self, "wait_until_ready", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 availability_zones: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 disk: Optional[pulumi.Input[_builtins.bool]] = None,
                 identify_by_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 scheduling: Optional[pulumi.Input['ClusterSchedulingArgs']] = None,
                 size: Optional[pulumi.Input[_builtins.str]] = None,
                 wait_until_ready: Optional[pulumi.Input['ClusterWaitUntilReadyArgs']] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] availability_zones: The specific availability zones of the cluster.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.bool] disk: **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        :param pulumi.Input[_builtins.bool] identify_by_name: Use the cluster name as the resource identifier in your state file, rather than the internal cluster ID. This is particularly useful in scenarios like dbt-materialize blue/green deployments, where clusters are swapped but the ID changes. By identifying by name, the resource can be managed consistently even when the underlying cluster ID is updated.
        :param pulumi.Input[_builtins.bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[_builtins.str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[_builtins.str] name: The identifier for the cluster.
        :param pulumi.Input[_builtins.str] ownership_role: The owernship role of the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.int] replication_factor: The number of replicas of each dataflow-powered object to maintain.
        :param pulumi.Input['ClusterSchedulingArgs'] scheduling: Defines the scheduling parameters for the cluster.
        :param pulumi.Input[_builtins.str] size: The size of the managed cluster.
        :param pulumi.Input['ClusterWaitUntilReadyArgs'] wait_until_ready: Defines the parameters for the WAIT UNTIL READY options
        """
        if availability_zones is not None:
            pulumi.set(__self__, "availability_zones", availability_zones)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if disk is not None:
            warnings.warn("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""", DeprecationWarning)
            pulumi.log.warn("""disk is deprecated: Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
        if disk is not None:
            pulumi.set(__self__, "disk", disk)
        if identify_by_name is not None:
            pulumi.set(__self__, "identify_by_name", identify_by_name)
        if introspection_debugging is not None:
            pulumi.set(__self__, "introspection_debugging", introspection_debugging)
        if introspection_interval is not None:
            pulumi.set(__self__, "introspection_interval", introspection_interval)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if ownership_role is not None:
            pulumi.set(__self__, "ownership_role", ownership_role)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if replication_factor is not None:
            pulumi.set(__self__, "replication_factor", replication_factor)
        if scheduling is not None:
            pulumi.set(__self__, "scheduling", scheduling)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if wait_until_ready is not None:
            pulumi.set(__self__, "wait_until_ready", wait_until_ready)

    @_builtins.property
    @pulumi.getter(name="availabilityZones")
    def availability_zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The specific availability zones of the cluster.
        """
        return pulumi.get(self, "availability_zones")

    @availability_zones.setter
    def availability_zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "availability_zones", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
    def disk(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        """
        return pulumi.get(self, "disk")

    @disk.setter
    def disk(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disk", value)

    @_builtins.property
    @pulumi.getter(name="identifyByName")
    def identify_by_name(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the cluster name as the resource identifier in your state file, rather than the internal cluster ID. This is particularly useful in scenarios like dbt-materialize blue/green deployments, where clusters are swapped but the ID changes. By identifying by name, the resource can be managed consistently even when the underlying cluster ID is updated.
        """
        return pulumi.get(self, "identify_by_name")

    @identify_by_name.setter
    def identify_by_name(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "identify_by_name", value)

    @_builtins.property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @introspection_debugging.setter
    def introspection_debugging(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "introspection_debugging", value)

    @_builtins.property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @introspection_interval.setter
    def introspection_interval(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "introspection_interval", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identifier for the cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @ownership_role.setter
    def ownership_role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ownership_role", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of replicas of each dataflow-powered object to maintain.
        """
        return pulumi.get(self, "replication_factor")

    @replication_factor.setter
    def replication_factor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "replication_factor", value)

    @_builtins.property
    @pulumi.getter
    def scheduling(self) -> Optional[pulumi.Input['ClusterSchedulingArgs']]:
        """
        Defines the scheduling parameters for the cluster.
        """
        return pulumi.get(self, "scheduling")

    @scheduling.setter
    def scheduling(self, value: Optional[pulumi.Input['ClusterSchedulingArgs']]):
        pulumi.set(self, "scheduling", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The size of the managed cluster.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "size", value)

    @_builtins.property
    @pulumi.getter(name="waitUntilReady")
    def wait_until_ready(self) -> Optional[pulumi.Input['ClusterWaitUntilReadyArgs']]:
        """
        Defines the parameters for the WAIT UNTIL READY options
        """
        return pulumi.get(self, "wait_until_ready")

    @wait_until_ready.setter
    def wait_until_ready(self, value: Optional[pulumi.Input['ClusterWaitUntilReadyArgs']]):
        pulumi.set(self, "wait_until_ready", value)


@pulumi.type_token("materialize:index/cluster:Cluster")
class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 availability_zones: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 disk: Optional[pulumi.Input[_builtins.bool]] = None,
                 identify_by_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 scheduling: Optional[pulumi.Input[Union['ClusterSchedulingArgs', 'ClusterSchedulingArgsDict']]] = None,
                 size: Optional[pulumi.Input[_builtins.str]] = None,
                 wait_until_ready: Optional[pulumi.Input[Union['ClusterWaitUntilReadyArgs', 'ClusterWaitUntilReadyArgsDict']]] = None,
                 __props__=None):
        """
        Clusters describe logical compute resources that can be used by sources, sinks, indexes, and materialized views. Managed clusters are created by setting the `size` attribute

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_cluster = materialize.Cluster("exampleCluster")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Clusters can be imported using the cluster id or name

        ```sh
        $ pulumi import materialize:index/cluster:Cluster example_cluster <region>:id:<cluster_id>
        ```

        To import using the cluster name, you need to set the `identify_by_name` attribute to true

        ```sh
        $ pulumi import materialize:index/cluster:Cluster example_cluster <region>:name:<cluster_name>
        ```

        Cluster id and information be found in the `mz_catalog.mz_clusters` table

        The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] availability_zones: The specific availability zones of the cluster.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.bool] disk: **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        :param pulumi.Input[_builtins.bool] identify_by_name: Use the cluster name as the resource identifier in your state file, rather than the internal cluster ID. This is particularly useful in scenarios like dbt-materialize blue/green deployments, where clusters are swapped but the ID changes. By identifying by name, the resource can be managed consistently even when the underlying cluster ID is updated.
        :param pulumi.Input[_builtins.bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[_builtins.str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[_builtins.str] name: The identifier for the cluster.
        :param pulumi.Input[_builtins.str] ownership_role: The owernship role of the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.int] replication_factor: The number of replicas of each dataflow-powered object to maintain.
        :param pulumi.Input[Union['ClusterSchedulingArgs', 'ClusterSchedulingArgsDict']] scheduling: Defines the scheduling parameters for the cluster.
        :param pulumi.Input[_builtins.str] size: The size of the managed cluster.
        :param pulumi.Input[Union['ClusterWaitUntilReadyArgs', 'ClusterWaitUntilReadyArgsDict']] wait_until_ready: Defines the parameters for the WAIT UNTIL READY options
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ClusterArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Clusters describe logical compute resources that can be used by sources, sinks, indexes, and materialized views. Managed clusters are created by setting the `size` attribute

        ## Example Usage

        ```python
        import pulumi
        import pulumi_materialize as materialize

        example_cluster = materialize.Cluster("exampleCluster")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Clusters can be imported using the cluster id or name

        ```sh
        $ pulumi import materialize:index/cluster:Cluster example_cluster <region>:id:<cluster_id>
        ```

        To import using the cluster name, you need to set the `identify_by_name` attribute to true

        ```sh
        $ pulumi import materialize:index/cluster:Cluster example_cluster <region>:name:<cluster_name>
        ```

        Cluster id and information be found in the `mz_catalog.mz_clusters` table

        The region is the region where the database is located (e.g. aws/us-east-1)

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 availability_zones: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 disk: Optional[pulumi.Input[_builtins.bool]] = None,
                 identify_by_name: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
                 introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 scheduling: Optional[pulumi.Input[Union['ClusterSchedulingArgs', 'ClusterSchedulingArgsDict']]] = None,
                 size: Optional[pulumi.Input[_builtins.str]] = None,
                 wait_until_ready: Optional[pulumi.Input[Union['ClusterWaitUntilReadyArgs', 'ClusterWaitUntilReadyArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["availability_zones"] = availability_zones
            __props__.__dict__["comment"] = comment
            __props__.__dict__["disk"] = disk
            __props__.__dict__["identify_by_name"] = identify_by_name
            __props__.__dict__["introspection_debugging"] = introspection_debugging
            __props__.__dict__["introspection_interval"] = introspection_interval
            __props__.__dict__["name"] = name
            __props__.__dict__["ownership_role"] = ownership_role
            __props__.__dict__["region"] = region
            __props__.__dict__["replication_factor"] = replication_factor
            __props__.__dict__["scheduling"] = scheduling
            __props__.__dict__["size"] = size
            __props__.__dict__["wait_until_ready"] = wait_until_ready
        super(Cluster, __self__).__init__(
            'materialize:index/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            availability_zones: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            disk: Optional[pulumi.Input[_builtins.bool]] = None,
            identify_by_name: Optional[pulumi.Input[_builtins.bool]] = None,
            introspection_debugging: Optional[pulumi.Input[_builtins.bool]] = None,
            introspection_interval: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            ownership_role: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
            scheduling: Optional[pulumi.Input[Union['ClusterSchedulingArgs', 'ClusterSchedulingArgsDict']]] = None,
            size: Optional[pulumi.Input[_builtins.str]] = None,
            wait_until_ready: Optional[pulumi.Input[Union['ClusterWaitUntilReadyArgs', 'ClusterWaitUntilReadyArgsDict']]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] availability_zones: The specific availability zones of the cluster.
        :param pulumi.Input[_builtins.str] comment: Comment on an object in the database.
        :param pulumi.Input[_builtins.bool] disk: **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        :param pulumi.Input[_builtins.bool] identify_by_name: Use the cluster name as the resource identifier in your state file, rather than the internal cluster ID. This is particularly useful in scenarios like dbt-materialize blue/green deployments, where clusters are swapped but the ID changes. By identifying by name, the resource can be managed consistently even when the underlying cluster ID is updated.
        :param pulumi.Input[_builtins.bool] introspection_debugging: Whether to introspect the gathering of the introspection data.
        :param pulumi.Input[_builtins.str] introspection_interval: The interval at which to collect introspection data.
        :param pulumi.Input[_builtins.str] name: The identifier for the cluster.
        :param pulumi.Input[_builtins.str] ownership_role: The owernship role of the object.
        :param pulumi.Input[_builtins.str] region: The region to use for the resource connection. If not set, the default region is used.
        :param pulumi.Input[_builtins.int] replication_factor: The number of replicas of each dataflow-powered object to maintain.
        :param pulumi.Input[Union['ClusterSchedulingArgs', 'ClusterSchedulingArgsDict']] scheduling: Defines the scheduling parameters for the cluster.
        :param pulumi.Input[_builtins.str] size: The size of the managed cluster.
        :param pulumi.Input[Union['ClusterWaitUntilReadyArgs', 'ClusterWaitUntilReadyArgsDict']] wait_until_ready: Defines the parameters for the WAIT UNTIL READY options
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["availability_zones"] = availability_zones
        __props__.__dict__["comment"] = comment
        __props__.__dict__["disk"] = disk
        __props__.__dict__["identify_by_name"] = identify_by_name
        __props__.__dict__["introspection_debugging"] = introspection_debugging
        __props__.__dict__["introspection_interval"] = introspection_interval
        __props__.__dict__["name"] = name
        __props__.__dict__["ownership_role"] = ownership_role
        __props__.__dict__["region"] = region
        __props__.__dict__["replication_factor"] = replication_factor
        __props__.__dict__["scheduling"] = scheduling
        __props__.__dict__["size"] = size
        __props__.__dict__["wait_until_ready"] = wait_until_ready
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="availabilityZones")
    def availability_zones(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The specific availability zones of the cluster.
        """
        return pulumi.get(self, "availability_zones")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Comment on an object in the database.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""Disk replicas are deprecated and will be removed in a future release. The `disk` attribute will be enabled by default for 'cc' clusters""")
    def disk(self) -> pulumi.Output[_builtins.bool]:
        """
        **Deprecated**. This attribute is maintained for backward compatibility with existing configurations. New users should use 'cc' sizes for disk access.
        """
        return pulumi.get(self, "disk")

    @_builtins.property
    @pulumi.getter(name="identifyByName")
    def identify_by_name(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Use the cluster name as the resource identifier in your state file, rather than the internal cluster ID. This is particularly useful in scenarios like dbt-materialize blue/green deployments, where clusters are swapped but the ID changes. By identifying by name, the resource can be managed consistently even when the underlying cluster ID is updated.
        """
        return pulumi.get(self, "identify_by_name")

    @_builtins.property
    @pulumi.getter(name="introspectionDebugging")
    def introspection_debugging(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to introspect the gathering of the introspection data.
        """
        return pulumi.get(self, "introspection_debugging")

    @_builtins.property
    @pulumi.getter(name="introspectionInterval")
    def introspection_interval(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The interval at which to collect introspection data.
        """
        return pulumi.get(self, "introspection_interval")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The identifier for the cluster.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="ownershipRole")
    def ownership_role(self) -> pulumi.Output[_builtins.str]:
        """
        The owernship role of the object.
        """
        return pulumi.get(self, "ownership_role")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region to use for the resource connection. If not set, the default region is used.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> pulumi.Output[_builtins.int]:
        """
        The number of replicas of each dataflow-powered object to maintain.
        """
        return pulumi.get(self, "replication_factor")

    @_builtins.property
    @pulumi.getter
    def scheduling(self) -> pulumi.Output[Optional['outputs.ClusterScheduling']]:
        """
        Defines the scheduling parameters for the cluster.
        """
        return pulumi.get(self, "scheduling")

    @_builtins.property
    @pulumi.getter
    def size(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The size of the managed cluster.
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter(name="waitUntilReady")
    def wait_until_ready(self) -> pulumi.Output[Optional['outputs.ClusterWaitUntilReady']]:
        """
        Defines the parameters for the WAIT UNTIL READY options
        """
        return pulumi.get(self, "wait_until_ready")

